@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.0-1
+# Application Name - Health Check V0.5.0-3
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -105,27 +105,29 @@ class Ui_MainWindow(object):
         self.lbl_Accel.setObjectName("lbl_Accel")
         self.lbl_Accel.setText("Accelerometer")
 
-        # Set up the GPS Info label
-        self.lbl_GpsPos = QtGui.QLabel(self.tab)
-        self.lbl_GpsPos.setGeometry(QtCore.QRect(10, 60, 141, 20))
-        self.lbl_GpsPos.setFont(font)
-        self.lbl_GpsPos.setObjectName("lbl_GpsPos")
-        self.lbl_GpsPos.setText("GPS Position")
-
         # This label will be used to show the Maemo Firmware version currently installed
         self.lbl_Maemo_Version = QtGui.QLabel(self.tab)
-        self.lbl_Maemo_Version.setGeometry(QtCore.QRect(10, 90, 141, 21))
+        self.lbl_Maemo_Version.setGeometry(QtCore.QRect(10, 60, 141, 21))
         self.lbl_Maemo_Version.setFont(font)
         self.lbl_Maemo_Version.setObjectName("lbl_Maemo_Version")
         self.lbl_Maemo_Version.setText("Firmware Ver")
 
         # This label is for the Rootfs Free space (Label only)
         self.lbl_rootfs = QtGui.QLabel(self.tab)
-        self.lbl_rootfs.setGeometry(QtCore.QRect(10, 120, 151, 21))
+        self.lbl_rootfs.setGeometry(QtCore.QRect(10, 90, 151, 21))
         self.lbl_rootfs.setFont(font)
         self.lbl_rootfs.setObjectName("lbl_rootfs")
         self.lbl_rootfs.setText("Rootfs Free")
 
+        # This label is for the Rootfs Free space (Label only)
+        self.lbl_mydocs = QtGui.QLabel(self.tab)
+        self.lbl_mydocs.setGeometry(QtCore.QRect(10, 120, 151, 21))
+        self.lbl_mydocs.setFont(font)
+        self.lbl_mydocs.setObjectName("lbl_mydocs")
+        self.lbl_mydocs.setText("MyDocs Free")
+
+        
+
         # This label is for the CPU Info Label only)
         self.lbl_Processor = QtGui.QLabel(self.tab)
         self.lbl_Processor.setGeometry(QtCore.QRect(10, 150, 151, 21))
@@ -147,50 +149,9 @@ class Ui_MainWindow(object):
         self.lbl_SysLocale.setObjectName("lbl_SysLocale")
         self.lbl_SysLocale.setText("System Locale")
 
-        # This label is for the phone signal (Label only)
-        self.lbl_Psignal = QtGui.QLabel(self.tab)
-        self.lbl_Psignal.setGeometry(QtCore.QRect(10, 240, 151, 21))
-        self.lbl_Psignal.setFont(font)
-        self.lbl_Psignal.setObjectName("lbl_Psignal")
-        self.lbl_Psignal.setText("Phone Signal")
-
-        # This label is for the phone RNC (Label only)
-        self.lbl_PRNC = QtGui.QLabel(self.tab)
-        self.lbl_PRNC.setGeometry(QtCore.QRect(10, 270, 151, 21))
-        self.lbl_PRNC.setFont(font)
-        self.lbl_PRNC.setObjectName("lbl_PRNC")
-        self.lbl_PRNC.setText("Network Status")
+       
         
-        # This label is for the Phone Services (Label only)
-        self.lbl_PhoneServices = QtGui.QLabel(self.tab)
-        self.lbl_PhoneServices.setGeometry(QtCore.QRect(10, 300, 151, 21))
-        self.lbl_PhoneServices.setFont(font)
-        self.lbl_PhoneServices.setObjectName("lbl_PhoneServices")
-        self.lbl_PhoneServices.setText("Phone Services")
-
-        # This label is for the Cell ID(Label only)
-        self.lbl_Cell_ID = QtGui.QLabel(self.tab)
-        self.lbl_Cell_ID.setGeometry(QtCore.QRect(10, 330, 151, 21))
-        self.lbl_Cell_ID.setFont(font)
-        self.lbl_Cell_ID.setObjectName("lbl_Cell_ID")
-        self.lbl_Cell_ID.setText("Phone Cell_ID")
         
-        # Set up the Front Camera label
-        self.lbl_FrontCam = QtGui.QLabel(self.tab)
-        self.lbl_FrontCam.setGeometry(QtCore.QRect(580, 10, 131, 21))
-        self.lbl_FrontCam.setFont(font)
-        self.lbl_FrontCam.setObjectName("lbl_FrontCam")
-        self.lbl_FrontCam.setText("Front Camera")
-
-        # This label is used to show the Front Camera widget
-        self.lbl_CameraShow = QtGui.QLabel(self.tab)
-        self.lbl_CameraShow.setGeometry(QtCore.QRect(510, 40, 281, 181))
-        self.lbl_CameraShow.setFrameShape(QtGui.QFrame.Panel)
-        self.lbl_CameraShow.setFrameShadow(QtGui.QFrame.Raised)
-        self.lbl_CameraShow.setLineWidth(2)
-        self.lbl_CameraShow.setMidLineWidth(1)
-        self.lbl_CameraShow.setScaledContents(True)
-        self.lbl_CameraShow.setObjectName("lbl_CameraShow")
 
         # Start showing the Information fields - these fields i have labelled with Info(mostly!), but only because it makes sense to me!
 
@@ -211,25 +172,24 @@ class Ui_MainWindow(object):
         self.lbl_Accel_Info.setFont(font)
         self.lbl_Accel_Info.setObjectName("lbl_Accel_Info")
 
-        # GPS Info Field
-        self.lbl_Gps_Info = QtGui.QLabel(self.tab)
-        self.lbl_Gps_Info.setGeometry(QtCore.QRect(160, 60, 381, 20))
-        self.lbl_Gps_Info.setObjectName("lbl_Gps_Info")
-        self.lbl_Gps_Info.setFont(font)
-
-        
         # Label to show the maemo firmware version Information
         self.lbl_Maemo_Ver_Info = QtGui.QLabel(self.tab)
-        self.lbl_Maemo_Ver_Info.setGeometry(QtCore.QRect(160, 90, 331, 21))
+        self.lbl_Maemo_Ver_Info.setGeometry(QtCore.QRect(160, 60, 331, 21))
         self.lbl_Maemo_Ver_Info.setFont(font)
         self.lbl_Maemo_Ver_Info.setObjectName("lbl_Maemo_Ver_Info")
 
         # Rootfs Info - label to show the rootfs free space (data)
         self.lbl_rootfd_info = QtGui.QLabel(self.tab)
-        self.lbl_rootfd_info.setGeometry(QtCore.QRect(160, 120, 331, 21))
+        self.lbl_rootfd_info.setGeometry(QtCore.QRect(160, 90, 331, 21))
         self.lbl_rootfd_info.setFont(font)
         self.lbl_rootfd_info.setObjectName("lbl_rootfd_info")
 
+        # Rootfs Info - label to show the rootfs free space (data)
+        self.lbl_mydocsd_info = QtGui.QLabel(self.tab)
+        self.lbl_mydocsd_info.setGeometry(QtCore.QRect(160, 120, 331, 21))
+        self.lbl_mydocsd_info.setFont(font)
+        self.lbl_mydocsd_info.setObjectName("lbl_mydocsd_info")
+
         # This label is for the CPU Information(Label only)
         self.lbl_ProcessorInfo = QtGui.QLabel(self.tab)
         self.lbl_ProcessorInfo.setGeometry(QtCore.QRect(160, 150, 331, 21))
@@ -250,35 +210,8 @@ class Ui_MainWindow(object):
         self.lbl_SysLocaleInfo.setFont(font)
         self.lbl_SysLocaleInfo.setObjectName("lbl_SysLocaleInfo")
         self.lbl_SysLocaleInfo.setText("Sys Locale Info")
+
         
-        # This label is for the Phone Signal info (Label only)
-        self.lbl_pSignal_Info = QtGui.QLabel(self.tab)
-        self.lbl_pSignal_Info.setGeometry(QtCore.QRect(160, 240, 331, 21))
-        self.lbl_pSignal_Info.setFont(font)
-        self.lbl_pSignal_Info.setObjectName("lbl_pSignal_Info")
-        self.lbl_pSignal_Info.setText("Phone Signal")
-
-        # This label was Phone RNC info now net status (Label only)
-        self.lbl_pRNC_Info = QtGui.QLabel(self.tab)
-        self.lbl_pRNC_Info.setGeometry(QtCore.QRect(160, 270, 331, 21))
-        self.lbl_pRNC_Info.setFont(font)
-        self.lbl_pRNC_Info.setObjectName("lbl_pRNC_Info")
-        self.lbl_pRNC_Info.setText("Network Status")
-
-        # This label is for the Phone services info (Label only)
-        self.lbl_pServices_Info = QtGui.QLabel(self.tab)
-        self.lbl_pServices_Info.setGeometry(QtCore.QRect(160, 300, 331, 21))
-        self.lbl_pServices_Info.setFont(font)
-        self.lbl_pServices_Info.setObjectName("lbl_pServices_Info")
-        self.lbl_pServices_Info.setText("Phone Services")
-
-        # This label is for the Cell ID info (Label only)
-        self.lbl_CellID_Info = QtGui.QLabel(self.tab)
-        self.lbl_CellID_Info.setGeometry(QtCore.QRect(160, 330, 331, 21))
-        self.lbl_CellID_Info.setFont(font)
-        self.lbl_CellID_Info.setObjectName("lbl_CellID_Info")
-        self.lbl_CellID_Info.setText("Cell ID")
-
         
         # Setup and draw the button
         self.pushButton_hw = QtGui.QPushButton(self.tab)
@@ -290,24 +223,148 @@ class Ui_MainWindow(object):
                 
         # Draw the Tab Contents
         self.tabWidget.addTab(self.tab, "")
+
         
-        # Start on tab 5!
+        # Start on tab 2!
         self.tab_2 = QtGui.QWidget()
         self.tab_2.setObjectName("tab_2")
 
+        # Set up the GPS Info label
+        self.lbl_GpsPos = QtGui.QLabel(self.tab_2)
+        self.lbl_GpsPos.setGeometry(QtCore.QRect(10, 60, 141, 20))
+        self.lbl_GpsPos.setFont(font)
+        self.lbl_GpsPos.setObjectName("lbl_GpsPos")
+        self.lbl_GpsPos.setText("GPS Position")
+        
+        # GPS Info Field
+        self.lbl_Gps_Info = QtGui.QLabel(self.tab_2)
+        self.lbl_Gps_Info.setGeometry(QtCore.QRect(160, 60, 381, 20))
+        self.lbl_Gps_Info.setObjectName("lbl_Gps_Info")
+        self.lbl_Gps_Info.setFont(font)
+
+        # This label is for the phone signal (Label only)
+        self.lbl_Psignal = QtGui.QLabel(self.tab_2)
+        self.lbl_Psignal.setGeometry(QtCore.QRect(10, 240, 151, 21))
+        self.lbl_Psignal.setFont(font)
+        self.lbl_Psignal.setObjectName("lbl_Psignal")
+        self.lbl_Psignal.setText("Phone Signal")
+
+        # This label is for the phone RNC (Label only)
+        self.lbl_PRNC = QtGui.QLabel(self.tab_2)
+        self.lbl_PRNC.setGeometry(QtCore.QRect(10, 270, 151, 21))
+        self.lbl_PRNC.setFont(font)
+        self.lbl_PRNC.setObjectName("lbl_PRNC")
+        self.lbl_PRNC.setText("Network Status")
+        
+        # This label is for the Phone Services (Label only)
+        self.lbl_PhoneServices = QtGui.QLabel(self.tab_2)
+        self.lbl_PhoneServices.setGeometry(QtCore.QRect(10, 300, 151, 21))
+        self.lbl_PhoneServices.setFont(font)
+        self.lbl_PhoneServices.setObjectName("lbl_PhoneServices")
+        self.lbl_PhoneServices.setText("Phone Services")
+
+        # This label is for the Cell ID(Label only)
+        self.lbl_Cell_ID = QtGui.QLabel(self.tab_2)
+        self.lbl_Cell_ID.setGeometry(QtCore.QRect(10, 330, 151, 21))
+        self.lbl_Cell_ID.setFont(font)
+        self.lbl_Cell_ID.setObjectName("lbl_Cell_ID")
+        self.lbl_Cell_ID.setText("Phone Cell_ID")
+        
+        # This label is for the Phone Signal info (Label only)
+        self.lbl_pSignal_Info = QtGui.QLabel(self.tab_2)
+        self.lbl_pSignal_Info.setGeometry(QtCore.QRect(160, 240, 331, 21))
+        self.lbl_pSignal_Info.setFont(font)
+        self.lbl_pSignal_Info.setObjectName("lbl_pSignal_Info")
+        #self.lbl_pSignal_Info.setText("Phone Signal")
+
+        # This label was Phone RNC info now net status (Label only)
+        self.lbl_pRNC_Info = QtGui.QLabel(self.tab_2)
+        self.lbl_pRNC_Info.setGeometry(QtCore.QRect(160, 270, 331, 21))
+        self.lbl_pRNC_Info.setFont(font)
+        self.lbl_pRNC_Info.setObjectName("lbl_pRNC_Info")
+        #self.lbl_pRNC_Info.setText("Network Status")
+
+        # This label is for the Phone services info (Label only)
+        self.lbl_pServices_Info = QtGui.QLabel(self.tab_2)
+        self.lbl_pServices_Info.setGeometry(QtCore.QRect(160, 300, 331, 21))
+        self.lbl_pServices_Info.setFont(font)
+        self.lbl_pServices_Info.setObjectName("lbl_pServices_Info")
+        #self.lbl_pServices_Info.setText("Phone Services")
+
+        # This label is for the Cell ID info (Label only)
+        self.lbl_CellID_Info = QtGui.QLabel(self.tab_2)
+        self.lbl_CellID_Info.setGeometry(QtCore.QRect(160, 330, 331, 21))
+        self.lbl_CellID_Info.setFont(font)
+        self.lbl_CellID_Info.setObjectName("lbl_CellID_Info")
+        #self.lbl_CellID_Info.setText("Cell ID")
+
+        # Setup and draw the button
+        self.pushButton_com = QtGui.QPushButton(self.tab_2)
+        self.pushButton_com.setGeometry(QtCore.QRect(580, 310, 211, 51))
+        self.pushButton_com.setObjectName("pushButton_com")
+        self.pushButton_com.setText("Update")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_com, QtCore.SIGNAL('clicked()'), self.updateTab2)
+
+        # Show the tab and draw contents
+        self.tabWidget.addTab(self.tab_2, "")
+
+        # Start on tab 3!
+        self.tab_3 = QtGui.QWidget()
+        self.tab_3.setObjectName("tab_3")
+
+        # Set up the Front Camera label
+        self.lbl_FrontCam = QtGui.QLabel(self.tab_3)
+        self.lbl_FrontCam.setGeometry(QtCore.QRect(10, 130, 131, 21))
+        self.lbl_FrontCam.setFont(font)
+        self.lbl_FrontCam.setObjectName("lbl_FrontCam")
+        self.lbl_FrontCam.setText("Front Camera")
+
+        # This label is used to show the Front Camera widget
+        self.lbl_CameraShow = QtGui.QLabel(self.tab_3)
+        self.lbl_CameraShow.setGeometry(QtCore.QRect(150, 10, 631, 341))
+        self.lbl_CameraShow.setFrameShape(QtGui.QFrame.Panel)
+        self.lbl_CameraShow.setFrameShadow(QtGui.QFrame.Raised)
+        self.lbl_CameraShow.setLineWidth(2)
+        self.lbl_CameraShow.setMidLineWidth(1)
+        self.lbl_CameraShow.setScaledContents(True)
+        self.lbl_CameraShow.setObjectName("lbl_CameraShow")
+        
+        # Setup and draw the button
+        self.pushButton_cam = QtGui.QPushButton(self.tab_3)
+        self.pushButton_cam.setGeometry(QtCore.QRect(0, 300, 151, 51))
+        self.pushButton_cam.setObjectName("pushButton_cam")
+        self.pushButton_cam.setText("Update")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
+
+        # Show the tab and draw contents
+        self.tabWidget.addTab(self.tab_3, "")
+
+        # Start on tab 4!
+        self.tab_4 = QtGui.QWidget()
+        self.tab_4.setObjectName("tab_4")
+
+
+
+    
+        self.tabWidget.addTab(self.tab_4, "")
+
+        # Start on tab 5!
+        self.tab_5 = QtGui.QWidget()
+        self.tab_5.setObjectName("tab_5")
+
         # Create the text browser to show the large console input
         # I have used this to show i could get the information in to begin with... I will eventually parse this information and put it into a list
         # box of some sort
-        self.textBrowser = QtGui.QTextBrowser(self.tab_2)
+        self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.0-2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.0-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
         self.textBrowser.setFont(font)
-
-        # Show the tab and draw contents
-        self.tabWidget.addTab(self.tab_2, "")
+        self.tabWidget.addTab(self.tab_5, "")
 
         # Draw the main Window
         MainWindow.setCentralWidget(self.centralwidget)
@@ -421,21 +478,22 @@ class Ui_MainWindow(object):
         gr = os.popen('df -h /').read()
         # Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
         gx = str(gr)[-14:]
-        gx = gx[:-3]
+        gx = gx[:-7]
         self.lbl_rootfd_info.setText(gx.strip())
+
+    def updatemydocs(self):
+        # Call the x-terminal command to read the rootfs free space
+        ge = os.popen('df -h /home/user/MyDocs').read()
+        # Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
+        gf = str(ge)[-34:]
+        print gf
+        gf = gf[:-24]
+        print gf
+        self.lbl_mydocsd_info.setText(gf.strip())
         
 # Funtion - update tab.... Originally to update tab1, but using it to collate the functions
 # It has the commented out message boxes, will work on this later
     def updateTab1(self):
-  
-        #import hildon
-        #import gtk     
-        
-        #dialog = gtk.Dialog()
-        #dialog.set_title("Updating... please wait")
-        #dialog.show_all()
-        #dialog.run()
-        #hildon.hildon_gtk_window_set_progress_indicator(dialog, 1)
         
         self.pushButton_hw.setEnabled(False)
         self.pushButton_hw.setText(".")
@@ -446,26 +504,43 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setText("...")
         Thread(target=self.updateCPU()).start()
         self.pushButton_hw.setText("....")
-        Thread(target=self.updateGPS()).start()
+        Thread(target=self.updatemydocs()).start()
         self.pushButton_hw.setText(".....")
         Thread(target=self.updateMaemoV()).start()
         self.pushButton_hw.setText("......")
-        Thread(target=self.updateImage()).start()
+        
         self.pushButton_hw.setText(".......")
         Thread(target=self.updateBatt()).start()
         self.pushButton_hw.setText("........")
-        Thread(target=self.Cellular()).start()
+        
         self.pushButton_hw.setText("Update")
         self.pushButton_hw.setEnabled(True)
 
+    def updateTab2(self):
+        self.pushButton_com.setEnabled(False)
+        self.pushButton_com.setText("...")
+        Thread(target=self.updateGPS()).start()
+        self.pushButton_com.setText(".....")
+        Thread(target=self.Cellular()).start()
+        self.pushButton_com.setText("Update")
+        self.pushButton_com.setEnabled(True)
+
+    def updateTab3(self):
+        self.pushButton_cam.setEnabled(False)
+        self.pushButton_cam.setText("....")
+        Thread(target=self.updateImage()).start()
+        self.pushButton_cam.setText("Update")
+        self.pushButton_cam.setEnabled(True)
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-2", None, QtGui.QApplication.UnicodeUTF8))
-        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System Information", None, QtGui.QApplication.UnicodeUTF8))
-        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
-
-
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-3", None, QtGui.QApplication.UnicodeUTF8))
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtGui.QApplication.translate("MainWindow", "Tools", None, QtGui.QApplication.UnicodeUTF8))
+        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_5), QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
+        
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
     def Cellular(self):
